==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>清除日志</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>您确定要清除该日志吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>近三天</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>近一周</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>近一个月</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>近三个月</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">导出</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>导 出</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>紧急</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>严重警告</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>严重</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>注意</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>调试</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登录</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>开机</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>非常严重</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>跟踪</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>正在导出...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>导出成功</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>导出失败</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>导出文件</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>周期：</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>级别：</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>应用列表：</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>状态：</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>事件类型：</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>主机名：</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>进程号：</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>动作：</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>开机记录</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>关机记录</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>登录信息</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>调试</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>紧急</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>严重警告</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>严重</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>注意</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>跟踪</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>非常严重</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>日志文件为空</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>日志收集工具</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>日志收集工具是一款查看系统日志的小工具。</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>级别</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>进程</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>时间</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>User</source>
        <translation>主机名</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>进程号</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>来源</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>动作</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>事件类型</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>级别：</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>进程：</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>时间：</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>信息：</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>主机名：</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>进程号：</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>时间</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>系统日志</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>内核日志</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>启动日志</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg日志</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin日志</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg日志</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>应用日志</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>开关机事件</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf日志</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>刷新频率</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>每10秒</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>每1分钟</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>每5分钟</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>不刷新</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>全部导出</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>系统全部日志</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>立即刷新</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>清除日志</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>您确定要清除该日志吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>近三天</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>近一周</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>近一个月</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>近三个月</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>导 出</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>全部</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>紧急</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>严重警告</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>严重</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>注意</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>调试</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登录</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>开机</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>非常严重</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>跟踪</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>身份鉴别</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>自主访问控制</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>强制访问控制</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>远程连接</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>文件审计</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>正在导出...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>导出成功</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>导出失败</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>导出目录不可用，请选择其他目录进行导出操作。</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>导出文件</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>周期：</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>级别：</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>状态：</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>事件类型：</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>主机名：</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>进程号：</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>动作：</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>开机记录</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>关机记录</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>登录信息</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>审计类型：</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>应用：</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>子模块：</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>调试</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>紧急</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>严重警告</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>严重</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>注意</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>跟踪</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>非常严重</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>日志文件为空</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>日志收集工具</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>日志收集工具是一款查看系统日志的小工具。</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>级别</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>进程</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>时间</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>User</source>
        <translation>主机名</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>进程号</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>来源</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>动作</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>事件类型</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>用户名</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>级别：</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>进程：</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>时间：</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>信息：</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>主机名：</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>进程号：</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>文件名称</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>崩溃信号</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>进程</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>核心文件</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>用户</translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>偏移量</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>时间</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>系统日志</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>内核日志</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>启动日志</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg日志</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin日志</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg日志</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>应用日志</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>开关机事件</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf日志</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>其它日志</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>自定义日志</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>审计日志</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>崩溃日志</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>无法获取崩溃信息，请安装 systemd-coredump。</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>无权限查看</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>当前系统安全等级为：高
仅审计管理员可查看审计日志</translation>
    </message>
    <message>
        <source>Audit log is not exist.</source>
        <translation>审计日志不存在。</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>导出日志到指定目录</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>导出路径</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>按日志种类导出日志</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>日志种类</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>按自研应用导出日志</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>自研应用名称</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>按时间周期导出日志</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>周期</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>按调试级别导出日志</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>调试级别</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>启动状态</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>按状态导出启动日志(klu)</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>按事件类型导出开关机事件/审计日志</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>事件类型</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>按关键词导出日志</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>关键词</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>上报崩溃埋点信息</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>按子模块导出应用日志</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>子模块</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>刷新频率</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>每10秒</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>每1分钟</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5分钟</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>不刷新</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>全部导出</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>立即刷新</translation>
    </message>
</context>
</TS>
